==> devchat-0.1.11.tar.gz: devchat-0.1.11/README.md <==
<div align="center">

![devchat](https://github.com/covespace/devchat/assets/592493/f39979fe-fe32-410b-bf9d-2118ac8ea3d5)

# DevChat

<br>

[![PRs Welcome](https://img.shields.io/badge/PRs-welcome-brightgreen.svg?style=flat-square)](http://makeapullrequest.com)
[![CircleCI](https://circleci.com/gh/covespace/devchat/tree/main.svg?style=shield)](https://circleci.com/gh/covespace/devchat/tree/main)
[![GitHub license](https://img.shields.io/github/license/covespace/devchat.svg)](https://github.com/covespace/devchat/blob/main/LICENSE)
[![Downloads](https://pepy.tech/badge/devchat)](https://pepy.tech/project/devchat)
[![PyPI version](https://badge.fury.io/py/devchat.svg)](https://badge.fury.io/py/devchat)
[![Discord Chat](https://img.shields.io/discord/1106908489114206309?logo=discord)](https://discord.gg/9t3yrbBUXD)

</div>
<br>
<div align="left">

The DevChat core library and CLI.

👉 **For an enhanced experience and UI, we welcome you to install [Visual Studio Code extension](https://github.com/covespace/devchat-vscode) from [Visual Studio Marketplace](https://marketplace.visualstudio.com/items?itemName=merico.devchat)! Enjoy DevChat VSCode!** 👏

***

## What is DevChat?

DevChat is the open-source solution to help you write prompts to generate code and documentation, going beyond simple code auto-completion.
It isn't limited to performing predefined operations on short code snippets.

DevChat is the way developers interact and collaborate with AI.

💬 Build the future with prompts, _not_ code.

## Why DevChat?

- Great output requires great input, to maximize the power of AI, DevChat assists you seamlessly to **provide the right context** to the AI.
    
  Chat history, code, files, directory trees, `git diff --cached`, or the output of any command.
  
  ![20230523-220717-cut-merged-1684855581224](https://github.com/covespace/devchat-vscode/assets/592493/16bc09e4-4185-4bcb-8d5a-2173b0bfc3ed)

  ![20230523-220717-00 00 28 206-00 00 44 950](https://github.com/covespace/devchat-vscode/assets/592493/d5556310-bc7f-4abb-86a3-8e76e4aa720e)  

- Once you have generated code with AI, DevChat **streamlines the actions** to properly integrate and ship.
  
  View diffs, copy or insert, commit & sync, or export to documentation, wikis, and more.
  
  ![20230523-220717-00 00 46 728-00 01 00 120](https://github.com/covespace/devchat-vscode/assets/592493/a2bab011-8e31-47a9-838f-36e43cd2e98c)

  ![20230523-220717-00 01 00 120-00 01 14 452](https://github.com/covespace/devchat-vscode/assets/592493/31e90fd5-e797-4726-b5b2-5c4dce1c7551)

- To guide AI in your work, define **your own workflows** with DevChat.
  
  ![20230523-220717-00 01 14 614-00 01 41 680](https://github.com/covespace/devchat-vscode/assets/592493/94502efd-781b-448d-b945-dffcc41d7af3)

  Explore more prompt templates, iterative calls to AI, and program operations.
  
- To ensure the experience fits your preferences, customize **your own experiences** with DevChat.
  
  Open-source, no waiting for opaque feature schedules. Access GPT-4 today and more models in the future.
  
## What is Prompt-Centric Software Development (PCSD)?

- The traditional code-centric paradigm is evolving.

- Write prompts to create code. Transform prompts into all the artifacts in software engineering.

  <img width="600" alt="image" src="https://github.com/covespace/devchat/assets/592493/dd32e900-92fd-4fa4-8489-96ed17ab5e0e">

  <sub>(This image is licensed by devchat.ai under a <a rel="license" href="http://creativecommons.org/licenses/by-sa/4.0/">Creative Commons Attribution-ShareAlike 4.0 International License</a>.)</sub>
  
- We like to call it DevPromptOps
  
  <img width="500" alt="image" src="https://github.com/covespace/devchat/assets/592493/e8e1215b-53b0-4473-ab00-0665d33f204a">
  
  <sub>(This image is licensed by devchat.ai under a <a rel="license" href="http://creativecommons.org/licenses/by-sa/4.0/">Creative Commons Attribution-ShareAlike 4.0 International License</a>.)</sub>

***

## Quick Start

**For UI, install our [Visual Studio Code extension](https://github.com/covespace/devchat-vscode) from [Visual Studio Marketplace](https://marketplace.visualstudio.com/items?itemName=merico.devchat).**

For CLI:
- Install DevChat by running: `pip install devchat`.
- Make sure you are working in a Git or SVN repository, as DevChat only works within one.
- Set your [OpenAI API Key](https://platform.openai.com/account/api-keys) by running `export OPENAI_API_KEY="[sk-...]"` (or DevChat access key).
- To access help, use the commands: `devchat --help` and `devchat prompt --help`.

## Community

- Join our [Discord](https://discord.gg/9t3yrbBUXD)!
- Participate in [discussions](https://github.com/covespace/devchat/discussions)!
- Chinese speaking users: 欢迎加入中文讨论组！

  <img width="300" alt="image" src="https://github.com/covespace/devchat-vscode/assets/592493/4407f1af-9f95-4dd4-b08f-e12125a0cf2c">

## Contributing

Issues and pull request are welcome: https://github.com/covespace/devchat/issues
  
## Roadmap

- [x] Implement code diff application.
- [ ] Improve code diff application using code change instructions.
- [ ] Develop a framework for defining workflows.
- [x] Implement topic management.
- [ ] Enable interaction with external development tools.
- [ ] Introduce more selective workflows.
  
## Contact
  
hello@merico.dev

We are creators of [Apache DevLake](https://devlake.apache.org/).

==> devchat-0.1.13.tar.gz: devchat-0.1.13/README.md <==
<div align="center">

![devchat](https://github.com/devchat-ai/devchat/assets/592493/f39979fe-fe32-410b-bf9d-2118ac8ea3d5)

# DevChat

<br>

[![PRs Welcome](https://img.shields.io/badge/PRs-welcome-brightgreen.svg?style=flat-square)](http://makeapullrequest.com)
[![CircleCI](https://circleci.com/gh/devchat-ai/devchat/tree/main.svg?style=shield)](https://circleci.com/gh/devchat-ai/devchat/tree/main)
[![GitHub license](https://img.shields.io/github/license/devchat-ai/devchat.svg)](https://github.com/devchat-ai/devchat/blob/main/LICENSE)
[![Downloads](https://pepy.tech/badge/devchat)](https://pepy.tech/project/devchat)
[![PyPI version](https://badge.fury.io/py/devchat.svg)](https://badge.fury.io/py/devchat)
[![Discord Chat](https://img.shields.io/discord/1106908489114206309?logo=discord)](https://discord.gg/9t3yrbBUXD)

</div>
<br>
<div align="left">

The DevChat core library and CLI.

👉 **For an enhanced experience and UI, we welcome you to install [Visual Studio Code extension](https://github.com/devchat-ai/devchat-vscode) from [Visual Studio Marketplace](https://marketplace.visualstudio.com/items?itemName=merico.devchat)! Enjoy DevChat VSCode!** 👏

***

## What is DevChat?

DevChat is the open-source solution to help you write prompts to generate code and documentation, going beyond simple code auto-completion.
It isn't limited to performing predefined operations on short code snippets.

DevChat is the way developers interact and collaborate with AI.

💬 Build the future with prompts, _not_ code.

## Why DevChat?

- Great output requires great input, to maximize the power of AI, DevChat assists you seamlessly to **provide the right context** to the AI.
    
  Chat history, code, files, directory trees, `git diff --cached`, or the output of any command.
  
  ![20230523-220717-cut-merged-1684855581224](https://github.com/devchat-ai/devchat-vscode/assets/592493/16bc09e4-4185-4bcb-8d5a-2173b0bfc3ed)

  ![20230523-220717-00 00 28 206-00 00 44 950](https://github.com/devchat-ai/devchat-vscode/assets/592493/d5556310-bc7f-4abb-86a3-8e76e4aa720e)  

- Once you have generated code with AI, DevChat **streamlines the actions** to properly integrate and ship.
  
  View diffs, copy or insert, commit & sync, or export to documentation, wikis, and more.
  
  ![20230523-220717-00 00 46 728-00 01 00 120](https://github.com/devchat-ai/devchat-vscode/assets/592493/a2bab011-8e31-47a9-838f-36e43cd2e98c)

  ![20230523-220717-00 01 00 120-00 01 14 452](https://github.com/devchat-ai/devchat-vscode/assets/592493/31e90fd5-e797-4726-b5b2-5c4dce1c7551)

- To guide AI in your work, define **your own workflows** with DevChat.
  
  ![20230523-220717-00 01 14 614-00 01 41 680](https://github.com/devchat-ai/devchat-vscode/assets/592493/94502efd-781b-448d-b945-dffcc41d7af3)

  Explore more prompt templates, iterative calls to AI, and program operations.
  
- To ensure the experience fits your preferences, customize **your own experiences** with DevChat.
  
  Open-source, no waiting for opaque feature schedules. Access GPT-4 today and more models in the future.
  
## What is Prompt-Centric Software Development (PCSD)?

- The traditional code-centric paradigm is evolving.

- Write prompts to create code. Transform prompts into all the artifacts in software engineering.

  <img width="600" alt="image" src="https://github.com/devchat-ai/devchat/assets/592493/dd32e900-92fd-4fa4-8489-96ed17ab5e0e">

  <sub>(This image is licensed by devchat.ai under a <a rel="license" href="http://creativecommons.org/licenses/by-sa/4.0/">Creative Commons Attribution-ShareAlike 4.0 International License</a>.)</sub>
  
- We like to call it DevPromptOps
  
  <img width="500" alt="image" src="https://github.com/devchat-ai/devchat/assets/592493/e8e1215b-53b0-4473-ab00-0665d33f204a">
  
  <sub>(This image is licensed by devchat.ai under a <a rel="license" href="http://creativecommons.org/licenses/by-sa/4.0/">Creative Commons Attribution-ShareAlike 4.0 International License</a>.)</sub>

***

## Quick Start

**For UI, install our [Visual Studio Code extension](https://github.com/devchat-ai/devchat-vscode) from [Visual Studio Marketplace](https://marketplace.visualstudio.com/items?itemName=merico.devchat).**

For CLI:
- Install DevChat by running: `pip install devchat`.
- Make sure you are working in a Git or SVN repository, as DevChat only works within one.
- Set your [OpenAI API Key](https://platform.openai.com/account/api-keys) by running `export OPENAI_API_KEY="[sk-...]"` (or DevChat access key).
- To access help, use the commands: `devchat --help` and `devchat prompt --help`.

## Community

- Join our [Discord](https://discord.gg/9t3yrbBUXD)!
- Participate in [discussions](https://github.com/devchat-ai/devchat/discussions)!
- Chinese speaking users: 欢迎加入中文讨论组！

  <img width="300" alt="image" src="https://github.com/devchat-ai/devchat-vscode/assets/592493/4407f1af-9f95-4dd4-b08f-e12125a0cf2c">

## Contributing

Issues and pull request are welcome: https://github.com/devchat-ai/devchat/issues
  
## Roadmap

- [x] Implement code diff application.
- [ ] Improve code diff application using code change instructions.
- [ ] Develop a framework for defining workflows.
- [x] Implement topic management.
- [ ] Enable interaction with external development tools.
- [ ] Introduce more selective workflows.
  
## Contact
  
hello@merico.dev

We are creators of [Apache DevLake](https://devlake.apache.org/).
